Module types

Module types 

Event and hook result types. Generic observe-only hook event types.

Domain-specific event types implement Event. Handlers receive read-only, concrete event references and can only return success or a typed HookError.

Structs

EventType
A string-based event type identifier.
HookError
Hook failure. Fatal errors are rare and may stop the owning loop.

Traits

Event
Trait that all hook and in-process bus events must implement.

Type Aliases

HookResult
The outcome returned by a hook handler.